pilas.actores.personajes_rpg

Package pilas :: Package actores :: Module personajes_rpg |
[hide private]
[frames] | no frames]

# Module personajes_rpg

source code

Classes | [hide private]
| BasePersonajeRPG Representa un personaje de juego tipo RPG.
| Esperando Un actor en posicion normal o esperando a que el usuario pulse alguna tecla.
| Caminando Representa al personaje caminando por el escenario.
| Calvo Representa un personaje de juego tipo RPG.
| Maton Representa un personaje de juego tipo RPG.

Variables | [hide private]
| VELOCIDAD = `100`
| NORTE = `0`
| SUR = `2`
| ESTE = `1`
| OESTE = `3`
| __package__ = ``'``pilas.actores``'``